﻿using System;
using System.Collections.Generic;
using System.Web;
using Libs;
using WRECWrapper.Responses;

namespace WRECWrapper
{
    public class OutputService
    {
        private readonly string m_token;
        private readonly string m_connectorURL;

        public OutputService(string token, string connectorURL)
        {
            m_token = token;
            m_connectorURL = connectorURL;
        }

        public IList<RealEstatePropertySummarySnapshot> GetRealEstatePropertySummarySnapshots(int realtorID)
        {
            var url = string.Format(@"{0}OutputService.svc/1/0/{1}/realestatesummary/?realtorid={2}", m_connectorURL, m_token, realtorID);
            var result = XmlLib.GetObject<RealEstatePropertySummarySnapshotResult>(url);
            if (!result.IsSuccess)
                throw new Exception(result.ErrorMessage);
            return result.ArrayOfRealEstatePropertySummarySnapshot;
        }

        public RealEstateProperty GetRealEstateProperty(int realtorID, int realEstateProperyID)
        {
            var url = string.Format(@"{0}OutputService.svc/1/0/{1}/realestate/?realtorid={2}&id={3}",
                m_connectorURL, m_token, realtorID, realEstateProperyID);
            var result = XmlLib.GetObject<RealEstatePropertyResult>(url);
            if (!result.IsSuccess)
                throw new Exception(result.ErrorMessage);
            return result.RealEstateProperty;
        }

        public void ConfirmRealEstatePropertyRetrieval(int realtorID, int realEstateProperyID, string mediaPartnerUrl, string message)
        {
            var url = string.Format(@"{0}OutputService.svc/1/0/{1}/realestate/?realtorid={2}&id={3}&action={4}&url={5}&message={6}",
                m_connectorURL, m_token, realtorID, realEstateProperyID, "confirm", HttpUtility.UrlEncode(mediaPartnerUrl), HttpUtility.UrlEncode(message));

            var result = HttpLib.PostMessage<DefaultResult>(url);
            if (!result.IsSuccess)
                throw new Exception(result.ErrorMessage ?? "Unknown error message.");
        }

        public void RejectRealEstatePropertyRetrieval(int realtorID, int realEstateProperyID, string message)
        {
            var url = string.Format(@"{0}OutputService.svc/1/0/{1}/realestate/?realtorid={2}&id={3}&action={4}&message={5}",
                m_connectorURL, m_token, realtorID, realEstateProperyID, "reject", HttpUtility.UrlEncode(message));

            var result = HttpLib.PostMessage<DefaultResult>(url);
            if (!result.IsSuccess)
                throw new Exception(result.ErrorMessage ?? "Unknown error message.");
        }
    }
}
